<?php

class Hm_Wp_Scss_Admin {

	private $plugin_name;
	private $version;

	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

		// Admin menu
		add_action('admin_menu', [$this,'hm_wp_scss_main_menu']);

		// Form fields
		add_action('admin_init', [$this, 'hm_wp_scss_fields']);

		// Check set folders
		if( !$this->scssFolderExists() )
			add_action( 'admin_notices', [$this,'admin_notice__error_scss'] );
		if( !$this->cssFolderExists() )
			add_action( 'admin_notices', [$this,'admin_notice__error_css'] );
		}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Hm_Wp_Scss_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Hm_Wp_Scss_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/hm-wp-scss-admin.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Hm_Wp_Scss_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Hm_Wp_Scss_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/hm-wp-scss-admin.js', array( 'jquery' ), $this->version, false );

	}

	/**
	 * Declare admin pages.
	 */
	public function hm_wp_scss_main_menu() {
		add_submenu_page( 'options-general.php', 'Happy SCSS Compiler', 'Happy SCSS Compiler', 'manage_options', 'happy-scss-compiler', [$this, 'happy_scss_compiler_main_settings'] );
	}

	/**
	 * Admin page content.
	 */
	public function happy_scss_compiler_main_settings() {
		$version = $this->version;
		require_once plugin_dir_path( __FILE__ ) . 'partials/hm_wp_scss_main_settings.php';
	}

	private function scssFolderExists()
	{
		return is_dir( get_stylesheet_directory() . get_option('hm_wp_scss__scss_location') );
	}
	private function cssFolderExists()
	{
		return is_dir( get_stylesheet_directory() . get_option('hm_wp_scss__css_location') );
	}

	/**
	 * Form fields
	 */
	public function hm_wp_scss_fields()
	{
		$page = 'hm-wp-scss';
		$titleIcon = '<span class="dashicons dashicons-block-default"></span>';
		$form = ['hm_wp_scss_sections' =>
			[
				'title' 		=> "$titleIcon Folder Paths",
				'description'	=> 'folderPathsDesc',
				'fields' 		=>
				[
					'hm_wp_scss__scss_location' => [
						'title'				=> 'SCSS Folder Path',
						'type'				=> 'input',
						'subtype'			=> 'text',
						'required' 			=> 'required',
						'get_options_list' 	=> '',
						'value_type'		=> 'normal',
						'wp_data' 			=> 'option'
					],
					'hm_wp_scss__css_location' => [
						'title'				=> 'CSS Folder Path',
						'type'				=> 'input',
						'subtype'			=> 'text',
						'required' 			=> 'required',
						'get_options_list' 	=> '',
						'value_type'		=> 'normal',
						'wp_data' 			=> 'option'
					],
				],
			],
			[
				'title' 		=> "$titleIcon Compilation",
				'description'	=> 'compilationDesc',
				'fields' 		=>
				[
					'hm_wp_scss__compilation_time' => [
						'title'				=> 'Compilation Time',
						'type'				=> 'select',
						'subtype'			=> '',
						'required' 			=> 'required',
						'get_options_list' 	=> 'Always|When SCSS has changed|If Logged In|If Admin Logged In',
						'value_type'		=> 'normal',
						'wp_data' 			=> 'option'
					],
					'hm_wp_scss__compilation_mode' => [
						'title'				=> 'Minification Mode',
						'type'				=> 'select',
						'subtype'			=> '',
						'required' 			=> 'required',
						'get_options_list' 	=> 'Compact|Compressed|Crunched|Debug|Expanded|Nested|OutputBlock',
						'value_type'		=> 'normal',
						'wp_data' 			=> 'option'
					],
					'hm_wp_scss__source_map_file' => [
						'title'				=> 'Enable Source Map File',
						'type'				=> 'input',
						'subtype'			=> 'checkbox',
						'required' 			=> 'required',
						'get_options_list' 	=> '',
						'value_type'		=> 'normal',
						'wp_data' 			=> 'option'
					],
					'hm_wp_scss__errors_display' => [
						'title'				=> 'Display Errors in Front Office',
						'type'				=> 'select',
						'subtype'			=> '',
						'required' 			=> '',
						'get_options_list' 	=> 'Always|If Debug Mode of Wordpress is true|If Logged In|If Admin Logged In|Never',
						'value_type'		=> 'normal',
						'wp_data' 			=> 'option'
					],
				]
			],
			[
				'title'		 	=> "$titleIcon Enqueuing CSS files",
				'description'	=> 'enqueuingCssFilesDesc',
				'fields' 		=>
				[
					'hm_wp_scss__enqueuing' => [
						'title'				=> 'Auto Enqueue CSS files',
						'type'				=> 'input',
						'subtype'			=> 'checkbox',
						'required' 			=> 'required',
						'get_options_list' 	=> '',
						'value_type'		=> 'normal',
						'wp_data' 			=> 'option'
					],
				]
			],
		];

		foreach( $form as $section_name => $section_data )
		{
			add_settings_section(
				$section_name,				// ID used to identify this section and with which to register options
				$section_data['title'],		// Title to be displayed on the administration page
				[$this,$section_data['description']],// Callback used to render the description of the section
				$page						// Page on which to add this section of options
			);
			foreach( $section_data['fields'] as $field_name => $field_data )
			{
				unset($args);
				$args = $field_data;
				$args['id'] = $field_name;
				$args['name'] = $field_name;

				add_settings_field(
					$field_name,
					$field_data['title'],
					[$this, 'plugin_name_render_settings_field'],
					$page,
					$section_name,
					$args
				);

				register_setting(
					$page,
					$field_name
				);
			}
		}

	}
	/**
	 * Section descriptions
	 */
	public function folderPathsDesc()
	{
		echo '<p>Set the path of the SCSS and CSS folders from your active (child) theme path.<br />The CSS folder will be automatically filled with generated files according to your SCSS folder.<br />Examples: <code>/assets/scss/</code> and <code>/assets/css/</code></p>';
	}
	public function compilationDesc()
	{
		echo '<p>Choose when you want to generate files, the minification level of your CSS, if you want to also generate Soure Map Files (for debugging), and when to display errors in front office to debug your SCSS code (errors will always be displayed in BO).</p>';
	}
	public function enqueuingCssFilesDesc()
	{
		echo '<p>Check below to automatically include all the generated CSS files in your header.</p>';
	}

	/**
	 * Notice an error
	 */
	function admin_notice__error( $_string ) {
		$class = 'notice notice-error';
		printf( '<div class="%1$s"><p><strong>%2$s</strong>%3$s</p></div>', esc_attr( $class ), esc_html( $_string ), esc_html( $this->error ) );
	}
	function admin_notice__error_scss( $_string ) {
		$class = 'notice notice-error';
		printf( '<div class="%1$s"><p><strong>%2$s</strong>%3$s</p></div>', esc_attr( $class ), 'Your SCSS folder doesn\'t exist in your active theme.', esc_html( $this->error ) );
	}
	function admin_notice__error_css( $_string ) {
		$class = 'notice notice-error';
		printf( '<div class="%1$s"><p><strong>%2$s</strong>%3$s</p></div>', esc_attr( $class ), 'Your CSS folder doesn\'t exist in your active theme.', esc_html( $this->error ) );
	}

	/**
	 * Function from https://blog.wplauncher.com/create-wordpress-plugin-settings-page/
	 */
	public function plugin_name_render_settings_field($args) {
		 /* EXAMPLE INPUT
				   'type'      => 'input',
				   'subtype'   => '',
				   'id'    => $this->plugin_name.'_example_setting',
				   'name'      => $this->plugin_name.'_example_setting',
				   'required' => 'required="required"',
				   'get_option_list' => "",
					 'value_type' = serialized OR normal,
		 'wp_data'=>(option or post_meta),
		 'post_id' =>
		 */
	   if($args['wp_data'] == 'option'){
			$wp_data_value = get_option($args['name']);
		} elseif($args['wp_data'] == 'post_meta'){
			$wp_data_value = get_post_meta($args['post_id'], $args['name'], true );
		}

		switch ($args['type']) {

			case 'input':
				$value = ($args['value_type'] == 'serialized') ? serialize($wp_data_value) : $wp_data_value;
				if($args['subtype'] != 'checkbox'){
					$prependStart = (isset($args['prepend_value'])) ? '<div class="input-prepend"> <span class="add-on">'.$args['prepend_value'].'</span>' : '';
					$prependEnd = (isset($args['prepend_value'])) ? '</div>' : '';
					echo '<div class="input-prepend"><span class="add-on"><input type="' . esc_attr($args['subtype']) . '" id="' . esc_attr($args['id']) . '" "' . esc_attr($args['required']) . '" name="' . esc_attr($args['name']) . '" size="40" value="' . esc_attr($value) . '" /></div>';

				} else {
					$checked = ($value) ? 'checked' : '';
					echo '<input type="'. esc_attr($args['subtype']) . '" id="' . esc_attr($args['id']) . '" "' . esc_attr($args['required']) . '" name="' . esc_attr($args['name']) . '" size="40" value="1" ' . esc_html($checked).' />';
				}
				break;
			case 'select':
				$value = ($args['value_type'] == 'serialized') ? serialize($wp_data_value) : $wp_data_value;
				echo '<select id="'.esc_attr($args['id']).'" name="'.esc_attr($args['name']).'">';
				foreach( explode('|',$args['get_options_list']) as $option )
				{
					echo '<option value="' . esc_html($option) . '"' . ( strtolower($value) == strtolower($option) ? ' selected="selected"' : '' ) . '>' . esc_html($option) . '</option>';
				}
				echo '</select>';
				break;
			default:
				break;
		}
	}
}
